@@ -60,9 +60,11 @@ class ApprcWatcher(CircusPlugin):
         self.loop_rate = config.get("loop_rate", 3)  # in seconds
         self.apprc = config.get("apprc", "/home/application/apprc")
         self.port = config.get("port", "8888")
-        self.period = ioloop.PeriodicCallback(FileWatcher(self.apprc, self.reload_env),
-                                              self.loop_rate * 1000,
-                                              self.loop)
+        self.period = ioloop.PeriodicCallback(
+            FileWatcher(self.apprc, self.reload_env),
+            self.loop_rate * 1000,
+            self.loop
+        )
 
     def handle_init(self):
         self.period.start()
@@ -132,13 +134,20 @@ class ProcfileWatcher(CircusPlugin):
         env = {"port": self.port, "PORT": self.port}
         env.update(common.load_envs(self.apprc))
         cmd = replace_args(cmd, **env)
+        stderr_stream = self.stderr_stream.copy()
+        stdout_stream = self.stdout_stream.copy()
+        stdout_stream["watcher_name"] = stderr_stream["watcher_name"] = name
         options = {
             "env": env,
             "copy_env": True,
             "working_dir": self.working_dir,
-            "stderr_stream": self.stderr_stream,
-            "stdout_stream": self.stdout_stream,
+            "stderr_stream": stderr_stream,
+            "stdout_stream": stdout_stream,
             "uid": self.uid,
+            "hooks": {
+                'before_start': ['tsuru.hooks.before_start', False],
+                'after_start': ['tsuru.hooks.after_start', False],
+            }
         }
         self.circus_client.call(json.dumps({
             "command": "add",
@@ -162,7 +171,8 @@ class ProcfileWatcher(CircusPlugin):
 
     def commands(self, procfile):
         cmds = self.call("status")["statuses"]
-        cmds_names = set([k for k in cmds.keys() if not k.startswith("plugin:")])
+        cmds_names = set([k for k in cmds.keys()
+                          if not k.startswith("plugin:")])
         new_cmds = set(procfile.commands.keys())
         to_remove = cmds_names.difference(new_cmds)
         to_add = new_cmds.difference(cmds_names)
