@@ -20,18 +20,21 @@ class Stream(object):
 
     def __init__(self, **kwargs):
         self.apprc = "/home/application/apprc"
+        self.watcher_name = kwargs.get("watcher_name", "")
 
     def __call__(self, data):
         appname, host, token = self.load_envs()
         if appname and host and token:
-            url = "{0}/apps/{1}/log".format(host, appname)
+            url = "{0}/apps/{1}/log?source={2}".format(host, appname,
+                                                       self.watcher_name)
             messages = extract_message(data["data"])
             requests.post(url, data=json.dumps(messages),
                           headers={"Authorization": "bearer " + token})
 
     def load_envs(self):
         envs = common.load_envs(self.apprc)
-        return envs.get("TSURU_APPNAME"), envs.get("TSURU_HOST"), envs.get("TSURU_APP_TOKEN")
+        return (envs.get("TSURU_APPNAME"), envs.get("TSURU_HOST"),
+                envs.get("TSURU_APP_TOKEN"))
 
     def close(self):
         pass
