@@ -24,9 +24,19 @@ class ProcfileWatcherTest(TestCase):
                     "env": {"port": "8888", "PORT": "8888"},
                     "copy_env": True,
                     "working_dir": "/home/application/current",
-                    "stderr_stream": {"class": "tsuru.stream.Stream"},
-                    "stdout_stream": {"class": "tsuru.stream.Stream"},
+                    "stderr_stream": {
+                        "class": "tsuru.stream.Stream",
+                        "watcher_name": name
+                    },
+                    "stdout_stream": {
+                        "class": "tsuru.stream.Stream",
+                        "watcher_name": name
+                    },
                     "uid": "ubuntu",
+                    "hooks": {
+                        "before_start": ["tsuru.hooks.before_start", False],
+                        "after_start": ["tsuru.hooks.after_start", False],
+                    }
                 },
                 "start": True,
             },
@@ -60,7 +70,8 @@ class ProcfileWatcherTest(TestCase):
 
     def test_commands_ignore_plugin(self):
         result = Mock()
-        result.return_value = {"statuses": {"plugin:tsuru-circus-ProcfileWatcher": "ok"}}
+        result.return_value = {"statuses":
+                               {"plugin:tsuru-circus-ProcfileWatcher": "ok"}}
         plugin = ProcfileWatcher("", "", 1)
         plugin.call = result
         procfile = Procfile('web: gunicorn -b 0.0.0.0:8080 abyss.wsgi\n')
